@@ -53,6 +53,6 @@ def _random_list(amount: int, choices: str, exclude: str = "") -> list:
     while i < amount:
         tmp = random.choice(choices)
         if tmp not in exclude:
-            result.append(random.choice(choices))
+            result.append(tmp)
             i += 1
     return result
